@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-37a7e2e7eea546355da7a2f6f1451bbc
-key: yesod_C7Q635V3q3u6JeqXkUFFF2
+id: yesod-1.4.2-014561294cc6d4aa41ebc57e41bd0950
+key: yesod_11PvuY0nsc26IUZmGoyOMe
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-C7Q635V3q3u6JeqXkUFFF2
+hs-libraries: HSyesod-1.4.2-11PvuY0nsc26IUZmGoyOMe
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -48,10 +48,10 @@ depends:
     wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
     warp-3.2.1-8f9aad771e0c137389da779f459b244d
     yaml-0.8.15.3-ab552a8419b21afe9697730ec885ddb9
-    yesod-auth-1.4.12-4c18f187cb9129ff1407662daa9c30b5
-    yesod-core-1.4.18.2-1c2aab5a100ce9de89ec3a6e919507f9
-    yesod-form-1.4.6-095d4629c01e27233d904c8ef131438d
-    yesod-persistent-1.4.0.3-98f957d1fa7a83a17c2fe07e134a809b
+    yesod-auth-1.4.12-02a50ce58851aa82a7e614caf77ff76f
+    yesod-core-1.4.19-b3a348ed8733808c727181b6d0df1b75
+    yesod-form-1.4.6-dba7ce4df3751045d7922517165296c5
+    yesod-persistent-1.4.0.3-32857d8c6898fe6060940215cdc2c4a2
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
